@@ -72,7 +72,11 @@ impl DocumentBuilder {
             bail!("No chapters found.");
         }
 
-        debug!("Building document with {} chapters.", chapters.len());
+        debug!(
+            "Building document with {} chapters:\n{:#?}",
+            chapters.len(),
+            chapters
+        );
         debug!("Using config: {:#?}", config);
 
         Ok(Document {
@@ -99,11 +103,15 @@ fn load_chapters<P: AsRef<Path>>(path: P, config: &Config) -> Result<Vec<Chapter
 
         WalkBuilder::new(path)
             .types(md_types)
+            .sort_by_file_path(Path::cmp)
             .build()
             .filter_map(|entry| entry.ok())
             .filter(|entry| entry.path().is_file())
             .map(|entry| Chapter::load(entry.path()))
-            .filter_map(|ch| ch.map_err(|err| warn!("{}. Skipping...", err)).ok())
+            .filter_map(|ch| {
+                ch.map_err(|err| warn!("{} Skipping this chapter...", err))
+                    .ok()
+            })
             .collect()
     };
 
@@ -112,7 +120,10 @@ fn load_chapters<P: AsRef<Path>>(path: P, config: &Config) -> Result<Vec<Chapter
             .iter()
             .filter_map(|val| val.as_str())
             .map(|p| Chapter::load(Path::new(p)))
-            .filter_map(|ch| ch.map_err(|err| warn!("{}. Skipping...", err)).ok())
+            .filter_map(|ch| {
+                ch.map_err(|err| warn!("{} Skipping this chapter...", err))
+                    .ok()
+            })
             .collect()),
 
         Some(toml::Value::String(path)) => {
