@@ -1,6 +1,7 @@
 #[macro_use]
 pub mod log;
 
+pub mod bib;
 pub mod config;
 pub mod document;
 pub mod errors;
@@ -10,3 +11,6 @@ pub use document::DocumentBuilder;
 pub use document::{Chapter, Document};
 
 pub use errors::Error;
+
+pub const CONFIG_FILE: &str = "mdoc.toml";
+pub const SRC_DIR: &str = "src";
